#include "testlib.h"
using namespace std;

static string output_secret = "2nr9nq14i40efnb3zzydxwm37y25fxrf2udp6vk7";
int n, m, q, q_used, a, b, c, d;
string contestant_solution;
vector<vector<int>> g; // grid

bool has_wall(int x, int y) {
    return (x<0 or x>=n or y<0 or y>=m or g[x][y]);
}

void mv(int &x, int &y, char inst) {
    // modifies the value of (x,y) according to the instruction
    int dx, dy;
    switch(inst) {
        case 'U':
            dx = -1;
            dy = 0;
            break;
        case 'D':
            dx = 1;
            dy = 0;
            break;
        case 'L':
            dx = 0;
            dy = -1;
            break;
        case 'R':
            dx = 0;
            dy = 1;
            break;
        default:
            quitf(_fail, "Unknown instruction character: '%c'", inst);
    }
    if(!has_wall(x+dx, y+dy)) {
        x = x+dx;
        y = y+dy;
    }
    return;
}

// executes all the instructions starting at (x,y)
// returns true if the robot successfully reaches (0,0)
void check(int x, int y) {
    //cerr << "check: " << x << " " << y << "\n";
    for(char c: contestant_solution) {
        mv(x, y, c);
        //cerr << "mv: " << x << " " << y << " " << c << "\n";
    }
    if(x!=0 or y!=0) {
        quit(_wa, "The path does not finish in (0,0)");
        //cerr << "fail: " << x << " " << y << "\n";
    }
}

int main(int argc, char * argv[]) {
	registerChecker("robot", argc, argv);

	readBothSecrets(output_secret);
	readBothGraderResults();

	inf.readLine(); // Input secret
	n = inf.readInt();
	m = inf.readInt();
	q = inf.readInt();
	a = inf.readInt();
	b = inf.readInt();
	c = inf.readInt();
	d = inf.readInt();

	q_used = ouf.readInt();
	if(q_used > q) {
        quit(_wa, "Too many instructions.");
	}
	ouf.readEoln();
	contestant_solution = ouf.readString();
	if((int)contestant_solution.length() != q_used) {
        quit(_fail, "Length of string does not match.");
	}

	g.resize(n);
	for(int i=0; i<n; i++) {
        for(int j=0; j<m; j++) {
            char tmp;
            do {
                tmp = inf.readChar();
            } while(isspace(tmp));
            if ('0' <= tmp && tmp <= '1') {
                g[i].push_back(tmp-'0');
            } else {
                quit(_fail, "Invalid cell character");
            }
        }
	}

	check(a,b);
	check(c,d);
    quit(_ok);
}
